@@ -1,8 +1,7 @@
 #!/usr/bin/python
 # vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
-app_name = 'gdrv'
-version = '0.0.a'
-config_paths = ['~/.config/', './']
+app_name = 'drivegoogle'
+config_paths = ['~/', './']
 config = None
 #service = None
